"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findSubtreeInPathByUrl = exports.findTreeInPath = exports.formatTitle = exports.getMdxSidebarTree = exports.globalStyles = exports.CODE_FONT = void 0;
exports.CODE_FONT = "'Fira Code',SFMono-Regular,Menlo,Monaco,\"Liberation Mono\",\"Courier New\",monospace,mono";
var startCase_1 = __importDefault(require("lodash/startCase"));
var react_1 = require("@emotion/react");
var cssForPdfRendering = react_1.css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    @media print {\n        /* basic styles */\n        body,\n        h1,\n        h2,\n        h3,\n        ol,\n        ul,\n        div {\n            position: static;\n            overflow: visible;\n            -webkit-print-color-adjust: exact;\n        }\n        div {\n            page-break-inside: avoid;\n        }\n        h2 {\n            page-break-before: always;\n        }\n        /* remove scroll bars */\n        ::-webkit-scrollbar {\n            display: none;\n        }\n        body {\n            -ms-overflow-style: none; /* IE and Edge */\n            scrollbar-width: none; /* Firefox */\n        }\n        .dokz.hiddenInPrint {\n            display: none !important;\n        }\n        .dokz.noMarginInPrint {\n            margin: 0px !important;\n        }\n        .dokz.codeContainer {\n            padding-top: 20px;\n        }\n        .dokz.mainContent {\n            border: none;\n            contain: none;\n            margin: 0px !important;\n            position: relative;\n            overflow: visible !important;\n            font-size: 15px;\n        }\n        /* force visibility and not overflow scroll */\n        #__next .dokz.visibleInPrint {\n            position: static !important;\n            contain: none;\n            overflow-y: visible !important;\n        }\n    }\n"], ["\n    @media print {\n        /* basic styles */\n        body,\n        h1,\n        h2,\n        h3,\n        ol,\n        ul,\n        div {\n            position: static;\n            overflow: visible;\n            -webkit-print-color-adjust: exact;\n        }\n        div {\n            page-break-inside: avoid;\n        }\n        h2 {\n            page-break-before: always;\n        }\n        /* remove scroll bars */\n        ::-webkit-scrollbar {\n            display: none;\n        }\n        body {\n            -ms-overflow-style: none; /* IE and Edge */\n            scrollbar-width: none; /* Firefox */\n        }\n        .dokz.hiddenInPrint {\n            display: none !important;\n        }\n        .dokz.noMarginInPrint {\n            margin: 0px !important;\n        }\n        .dokz.codeContainer {\n            padding-top: 20px;\n        }\n        .dokz.mainContent {\n            border: none;\n            contain: none;\n            margin: 0px !important;\n            position: relative;\n            overflow: visible !important;\n            font-size: 15px;\n        }\n        /* force visibility and not overflow scroll */\n        #__next .dokz.visibleInPrint {\n            position: static !important;\n            contain: none;\n            overflow-y: visible !important;\n        }\n    }\n"])));
exports.globalStyles = react_1.css(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    * {\n        box-sizing: border-box;\n    }\n    html {\n        height: 100%;\n    }\n    #__next {\n        min-height: 100%;\n        overflow-x: hidden;\n    }\n    body {\n        height: 100%;\n        overflow-y: scroll;\n        scroll-behavior: smooth;\n        -webkit-font-smoothing: antialiased;\n        -moz-osx-font-smoothing: grayscale;\n        text-rendering: optimizeLegibility;\n    }\n    ul.dokz {\n        list-style-type: none;\n    }\n    .dokz.mainContent {\n        -webkit-overflow-scrolling: touch;\n    }\n\n    ", "\n"], ["\n    * {\n        box-sizing: border-box;\n    }\n    html {\n        height: 100%;\n    }\n    #__next {\n        min-height: 100%;\n        overflow-x: hidden;\n    }\n    body {\n        height: 100%;\n        overflow-y: scroll;\n        scroll-behavior: smooth;\n        -webkit-font-smoothing: antialiased;\n        -moz-osx-font-smoothing: grayscale;\n        text-rendering: optimizeLegibility;\n    }\n    ul.dokz {\n        list-style-type: none;\n    }\n    .dokz.mainContent {\n        -webkit-overflow-scrolling: touch;\n    }\n\n    ", "\n"])), cssForPdfRendering);
function getMdxSidebarTree() {
    try {
        return require('nextjs_root_folder_/sidebar.json');
    }
    catch (_a) {
        return {
            name: 'pages',
            children: [],
        };
    }
}
exports.getMdxSidebarTree = getMdxSidebarTree;
function formatTitle(name) {
    return capitalizeFirstLetter(startCase_1.default(name.replace(/\.mdx?/, '')));
}
exports.formatTitle = formatTitle;
function capitalizeFirstLetter(string) {
    return string.charAt(0).toUpperCase() + string.slice(1);
}
function findTreeInPath(tree, path) {
    var _a;
    // remove leading and trailing slashes
    path = path.replace(/^\/|\/$/g, '');
    if (!((_a = tree === null || tree === void 0 ? void 0 : tree.children) === null || _a === void 0 ? void 0 : _a.length)) {
        return null;
    }
    if (tree.path === path) {
        return tree;
    }
    for (var _i = 0, _b = tree.children; _i < _b.length; _i++) {
        var child = _b[_i];
        var found = findTreeInPath(child, path);
        if (found) {
            return found;
        }
    }
}
exports.findTreeInPath = findTreeInPath;
function findSubtreeInPathByUrl(tree, url) {
    var _a;
    if (!((_a = tree === null || tree === void 0 ? void 0 : tree.children) === null || _a === void 0 ? void 0 : _a.length)) {
        return null;
    }
    for (var i = 0; i < tree.children.length; i++) {
        var child = tree.children[i];
        if (child.url && child.url.replace(/\/$/, '') === url) {
            return {
                previous: tree.children[i - 1],
                current: tree,
                next: tree.children[i + 1],
            };
        }
        var found = findSubtreeInPathByUrl(child, url);
        if (found) {
            return found;
        }
    }
}
exports.findSubtreeInPathByUrl = findSubtreeInPathByUrl;
var templateObject_1, templateObject_2;
