"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withDokz = void 0;
var chokidar_1 = __importDefault(require("chokidar"));
var throttle_1 = __importDefault(require("lodash/throttle"));
var fs_1 = __importDefault(require("fs"));
var fp_1 = require("lodash/fp");
var path_1 = __importDefault(require("path"));
var remark_extract_frontmatter_1 = __importDefault(require("remark-extract-frontmatter"));
var remark_frontmatter_1 = __importDefault(require("remark-frontmatter"));
var remark_mdx_metadata_1 = __importDefault(require("remark-mdx-metadata"));
var remark_slug_1 = __importDefault(require("remark-slug"));
var yaml_1 = __importDefault(require("yaml"));
var generateTableOfContents_1 = require("./generateTableOfContents");
var getMdxFilesIndex_1 = require("./getMdxFilesIndex");
var playground_1 = require("./rehype/playground");
var withMdx_1 = require("./withMdx");
var support_1 = require("../components/support");
var EXTENSIONS_TO_WATCH = ['.mdx', '.md'];
function withDokz(nextConfig) {
    if (nextConfig === void 0) { nextConfig = {}; }
    // .on('change', writeMdxIndex)
    nextConfig.pageExtensions = unique(__spreadArrays((nextConfig.pageExtensions || []), [
        'mdx',
    ]));
    return withMdx_1.withMdx({
        extension: /\.mdx?$/,
        onStart: function (_, options) {
            // only run once
            if (options.isServer) {
                return;
            }
            writeMdxIndex();
            if (process.env.NODE_ENV !== 'production') {
                var watcher = chokidar_1.default.watch(['./**/*.mdx', './**/*.md'], {
                    persistent: true,
                    ignoreInitial: true,
                });
                watcher.on('change', onFileChange);
                watcher.on('add', onFileChange);
                watcher.on('unlink', onFileChange);
            }
            else {
                writeMdxIndex();
            }
        },
        options: {
            remarkPlugins: [
                remark_frontmatter_1.default,
                [remark_extract_frontmatter_1.default, { yaml: yaml_1.default.parse }],
                remark_slug_1.default,
                function () { return function (tree, vfile) {
                    var tableOfContents = generateTableOfContents_1.generateTableOfContents(tree);
                    // console.log(vfile)
                    var cwd = vfile.cwd, contents = vfile.contents, _a = vfile.history, history = _a === void 0 ? [] : _a, data = vfile.data;
                    var filePath = history[0] || '';
                    if (process.env.DEBUG) {
                        console.log('frontmatter', data);
                    }
                    var plugin = fp_1.pipe(remark_mdx_metadata_1.default({
                        meta: __assign(__assign({ 
                            // lastEdited: `${new Date().toISOString()}`,
                            name: support_1.formatTitle(filePath.split('/').slice(-1)[0] || '') }, data), { tableOfContents: tableOfContents }),
                    }));
                    plugin(tree);
                }; },
            ],
            rehypePlugins: [playground_1.injectCodeToPlayground],
        },
    })(nextConfig);
}
exports.withDokz = withDokz;
function onFileChange(name) {
    var ext = path_1.default.extname(name);
    if (!EXTENSIONS_TO_WATCH.includes(ext)) {
        return;
    }
    writeMdxIndex();
}
var writeMdxIndex = throttle_1.default(function () {
    console.log('[ info ]  generating mdx sidebar file');
    return getMdxFilesIndex_1.getMdxFilesIndex()
        .then(function (index) {
        return fs_1.default.promises.writeFile('sidebar.json', JSON.stringify(index, null, 4));
    })
        .catch(function (e) {
        console.error('could not write mdx sidebar file');
        console.error(e);
    });
}, 2000);
function unique(arr) {
    var u = {}, a = [];
    for (var i = 0, l = arr.length; i < l; ++i) {
        if (!u.hasOwnProperty(arr[i])) {
            a.push(arr[i]);
            u[arr[i]] = 1;
        }
    }
    return a;
}
