"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.injectCodeToPlayground = exports.playgroundRegex = void 0;
var flatten_1 = __importDefault(require("lodash/flatten"));
var hast_util_to_string_1 = __importDefault(require("hast-util-to-string"));
var format_1 = require("./utils/format");
var jsx_1 = require("./utils/jsx");
var imports_1 = require("./utils/imports");
var exports_1 = require("./utils/exports");
var isPlayground = function (name) {
    return name === 'Playground';
};
var addComponentsProps = function (scopes) { return function (node, idx) {
    var name = jsx_1.componentName(node.value);
    var tagOpen = new RegExp("^\\<" + name);
    var formatted = format_1.formatter(hast_util_to_string_1.default(node));
    var code = formatted.slice(1, Infinity);
    var scope = "{props, " + scopes.join(',') + "}";
    var child = jsx_1.sanitizeCode(jsx_1.removeTags(code));
    var newTag = "<" + name + " __position={" + idx + "} code={'" + child + "'} scope={" + scope + "}";
    // console.log(newTag)
    node.value = node.value.replace(tagOpen, newTag);
}; };
exports.playgroundRegex = /<Playground\b/;
exports.injectCodeToPlayground = function () { return function (tree, file) {
    if (file.contents.search(exports.playgroundRegex) == -1) {
        return tree;
    }
    var playgroundComponents = tree.children
        .filter(function (node) { return node.type === 'jsx'; })
        .filter(function (node) {
        var name = jsx_1.componentName(node.value);
        return isPlayground(name);
    });
    var importNodes = tree.children.filter(function (n) { return n.type === 'import'; });
    var exportNodes = tree.children.filter(function (n) { return n.type === 'export'; });
    var importedScopes = flatten_1.default(importNodes.map(imports_1.getImportsVariables));
    var exportedScopes = flatten_1.default(exportNodes.map(exports_1.getExportsVariables)); // TODO exports not working, migrate to es lexer
    // filter added to avoid throwing if an unexpected type is exported
    var scopes = __spreadArrays(importedScopes, exportedScopes).filter(Boolean);
    playgroundComponents.forEach(addComponentsProps(scopes));
    return tree;
}; };
