var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { Box, Button, Divider, Stack, useClipboard, useColorMode, } from '@chakra-ui/react';
import flatten from 'lodash/fp/flatten';
import { Resizable } from 're-resizable';
import React, { useCallback, useEffect, useState, } from 'react';
import Frame from 'react-frame-component';
import { LiveEditor, LiveError, LivePreview, LiveProvider, } from 'react-live';
import { useDokzConfig } from '../provider';
import { CopyButton } from './Code';
import { mdx } from '@mdx-js/react';
import { CODE_FONT } from './support';
export var Playground = function (_a) {
    var className = _a.className, _b = _a.children, children = _b === void 0 ? null : _b, code = _a.code, scope = _a.scope, _c = _a.iframe, iframe = _c === void 0 ? false : _c, _d = _a.previewEnabled, previewEnabled = _d === void 0 ? true : _d, rest = __rest(_a, ["className", "children", "code", "scope", "iframe", "previewEnabled"]);
    var prismTheme = useDokzConfig().prismTheme;
    var _e = useState(code), editorCode = _e[0], setEditorCode = _e[1];
    var colorMode = useColorMode().colorMode;
    var language = className && className.replace(/language-/, '');
    var _f = useState(!previewEnabled), showCode = _f[0], setShowCode = _f[1];
    var _g = useClipboard(editorCode), onCopy = _g.onCopy, hasCopied = _g.hasCopied;
    var _h = React.useState('100%'), width = _h[0], setWidth = _h[1];
    var _j = useState(''), _ = _j[0], forceRender = _j[1];
    var resizableProps = getResizableProps(width, setWidth);
    var BUTTON_BG = colorMode === 'light' ? 'gray.100' : 'whiteAlpha.200';
    var liveProviderProps = {
        theme: prismTheme[colorMode],
        language: language,
        code: editorCode,
        // transformCode: (code) => '/** @jsx mdx */' + code,
        scope: __assign(__assign({}, scope), { mdx: mdx }),
    };
    var handleCodeChange = useCallback(function (newCode) { return setEditorCode(newCode.trim()); }, [setEditorCode]);
    var editorBar = (React.createElement(React.Fragment, null,
        React.createElement(Stack, { spacing: '20px', h: 'auto', w: '100%', isInline: true, flexDir: 'row', align: 'center', bg: { light: 'white', dark: 'gray.700' }[colorMode], p: '10px' },
            React.createElement(Box, { h: '1', flex: '1' }),
            React.createElement(Button, { transition: 'background 300ms', bg: !showCode ? BUTTON_BG : 'transparent', onClick: function () { return setShowCode(false); }, size: 'sm' }, "Preview"),
            React.createElement(Button, { transition: 'background 300ms', bg: showCode ? BUTTON_BG : 'transparent', onClick: function () { return setShowCode(true); }, size: 'sm' }, "Code"),
            React.createElement(CopyButton, { hasCopied: hasCopied, style: { strokeWidth: '2px' }, onClick: onCopy })),
        React.createElement(Divider, { m: '0' })));
    var livePreview = (React.createElement(Box, { as: LivePreview, fontFamily: 'body', p: '0px', height: 'auto', w: '100%', maxWidth: '100%', overflow: 'hidden' }));
    return (React.createElement(Box, __assign({ my: '20px' }, rest),
        React.createElement(Resizable, __assign({}, resizableProps, { handleComponent: { right: React.createElement(HandleComponent, { height: '100%' }) } }),
            React.createElement(LiveProvider, __assign({}, liveProviderProps),
                React.createElement(Stack, { w: '100%', maxWidth: '100%', borderWidth: '1px', 
                    // borderColor='inherit'
                    borderRadius: '8px', overflow: 'hidden', height: 'auto', shadow: 'lg', spacing: '0px', isInline: true },
                    React.createElement(Stack, { maxWidth: '100%', height: '100%', spacing: '0px', flex: '1' },
                        previewEnabled && editorBar,
                        React.createElement(Stack, { flex: '1', maxW: '100%', minW: '100%', display: !showCode ? 'block' : 'none' }, iframe ? (React.createElement(IframeWrapper, { onMount: forceRender }, livePreview)) : (livePreview)),
                        showCode && (React.createElement(LiveEditor, { onChange: handleCodeChange, style: liveEditorStyle })),
                        React.createElement(LiveError, { style: liveErrorStyle })))))));
};
var liveErrorStyle = {
    fontFamily: 'Menlo, monospace',
    fontSize: 14,
    padding: '1em',
    overflowX: 'auto',
    color: 'white',
    backgroundColor: 'red',
};
var liveEditorStyle = {
    fontSize: '0.9em',
    overflowX: 'auto',
    margin: 0,
    fontFamily: CODE_FONT,
    overflow: 'hidden',
};
var HandleComponent = function (props) {
    var colorMode = useColorMode().colorMode;
    return (React.createElement(Stack, __assign({ width: '20px', py: '10px', align: 'center', justify: 'center', borderWidth: '1px', 
        // borderColor='gray.300'
        bg: { light: 'gray.100', dark: 'gray.700' }[colorMode], borderRadius: '0 4px 4px 0' }, props),
        React.createElement(Box, { width: '8px', height: '40px', borderLeft: '2px solid', borderRight: '2px solid', borderColor: 'gray.300' })));
};
var getResizableProps = function (width, setWidth) { return ({
    minWidth: 260,
    maxWidth: '100%',
    size: {
        width: width,
        height: 'auto',
    },
    style: {
        margin: 0,
        marginRight: 'auto',
        height: 'auto',
    },
    enable: {
        top: false,
        right: true,
        bottom: false,
        left: false,
        topRight: false,
        bottomRight: false,
        bottomLeft: false,
        topLeft: false,
    },
    onResizeStop: function (e, direction, ref) {
        setWidth(ref.style.width);
    },
}); };
function getEmotionStyle() {
    var css = flatten(__spreadArrays(document.querySelectorAll('[data-emotion]')).map(function (_a) {
        var sheet = _a.sheet;
        return __spreadArrays(sheet.cssRules).map(function (rules) { return rules.cssText; });
    })).join('\n');
    var style = document.createElement('style');
    style.type = 'text/css';
    style.appendChild(document.createTextNode(css));
    style.setAttribute('EmotionExtractedCss', 'true');
    return style;
}
var CLEAR_PADDING = "<style> body { padding: 0; margin: 0; width: 100%; height: auto !important; }  </style>";
var INITIAL_IFRAME_CONTENT = "<!DOCTYPE html><html><head> " + CLEAR_PADDING + " </head><body><div></div></body></html>";
export var IframeWrapper = function (_a) {
    var children = _a.children, onMount = _a.onMount, _b = _a.style, style = _b === void 0 ? {} : _b, rest = __rest(_a, ["children", "onMount", "style"]);
    var _c = useState(0), height = _c[0], setHeight = _c[1];
    var iframeRef = React.createRef();
    var handleResize = function (iframe) {
        if (iframe.current &&
            iframe.current.node.contentDocument &&
            iframe.current.node.contentDocument.body.scrollHeight !== 0) {
            setHeight(iframe.current.node.contentDocument.body.scrollHeight);
        }
    };
    /**
     * Because <iframe> serves content in an isolated browsing context (document environment),
     * Styles in parent browsing context will not be available to <iframe> content,
     * we need to manually copy styles from parent browsing context to <iframe> browsing context
     */
    var copyStyles = function (ref) {
        var _a, _b;
        var iFrameNode = (_a = ref.current) === null || _a === void 0 ? void 0 : _a.node;
        if (!((_b = iFrameNode === null || iFrameNode === void 0 ? void 0 : iFrameNode.contentDocument) === null || _b === void 0 ? void 0 : _b.body)) {
            return;
        }
        // Copy <link> elements
        var links = Array.from(document.getElementsByTagName('link'));
        links.forEach(function (link) {
            if (link.rel === 'stylesheet') {
                iFrameNode.contentDocument.head.appendChild(link.cloneNode(true));
            }
        });
        // Copy <style> elements
        var styles = Array.from(document.head.getElementsByTagName('style'));
        styles.push(getEmotionStyle());
        styles.forEach(function (style) {
            iFrameNode.contentDocument.head.appendChild(style.cloneNode(true));
        });
    };
    useEffect(function () {
        // copyStyles(iframeRef)
        handleResize(iframeRef);
    }, [children]);
    useEffect(function () {
        onMount();
    }, []);
    return (React.createElement(Frame, { style: __assign(__assign({}, style), { width: '100%', height: height }), ref: iframeRef, initialContent: INITIAL_IFRAME_CONTENT, onLoad: function () {
            copyStyles(iframeRef);
            handleResize(iframeRef);
        } }, children));
};
var sleep = function (t) { return new Promise(function (r) { return setTimeout(r, t); }); };
