var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { Box, Stack, Divider, useDisclosure, Collapse, } from '@chakra-ui/react';
import orderBy from 'lodash/orderBy';
import React, { useEffect } from 'react';
import { ComponentLink } from './NavLink';
import { useAnimationComponent, useDokzConfig, } from '../provider';
import { useStorageState } from 'react-storage-hooks';
import { formatTitle, findTreeInPath } from './support';
var MDX_EXTENSION_REGEX = /\.mdx?/;
export var SideNav = function (_a) {
    var tree = _a.tree, rest = __rest(_a, ["tree"]);
    // console.log({ tree })
    var _b = useDokzConfig(), sidebarOrdering = _b.sidebarOrdering, _c = _b.docsRootPath, docsRootPath = _c === void 0 ? 'pages' : _c;
    tree = applySidebarOrdering({ tree: tree, order: sidebarOrdering });
    // console.log(tree)
    tree = findTreeInPath(tree, docsRootPath) || tree;
    // console.log(tree)
    if (!tree) {
        console.error(new Error("sidenav tree is null"));
        tree = { name: '', children: [] };
    }
    var Faded = useAnimationComponent();
    return (React.createElement(Box
    // borderRightWidth='1px'
    // minWidth='240px'
    , __assign({ 
        // borderRightWidth='1px'
        // minWidth='240px'
        overflowY: 'auto', as: 'nav', "aria-label": 'Main navigation', py: '6', pr: '6' }, rest),
        React.createElement(Box, { as: Faded, cascade: true }, tree.children.map(function (x) { return (React.createElement(NavTreeComponent, __assign({ hideDivider: true, key: x.path || x.title }, x))); }))));
};
function equalWithoutExtension(a, b) {
    return (a.replace(MDX_EXTENSION_REGEX, '') ===
        b.replace(MDX_EXTENSION_REGEX, ''));
}
export function applySidebarOrdering(_a) {
    var order = _a.order, tree = _a.tree;
    order = order || {};
    if (!tree.children) {
        return tree;
    }
    // put the non listed entries last
    tree.children = orderBy(tree.children, function (x) {
        var index = Object.keys(order).findIndex(function (k) {
            return equalWithoutExtension(k, x.name);
        });
        if (index === -1) {
            return Infinity;
        }
        return index;
    });
    // put the folders last
    tree.children = orderBy(tree.children, function (x, i) {
        var _a;
        if ((_a = x === null || x === void 0 ? void 0 : x.children) === null || _a === void 0 ? void 0 : _a.length) {
            return Infinity;
        }
        return 0;
    });
    // remove entries with `false` value
    tree.children = tree.children.filter(function (x) {
        var found = Object.keys(order).find(function (k) {
            return equalWithoutExtension(k, x.name);
        });
        if (found && order[found] === false) {
            return false;
        }
        return true;
    });
    // recurse
    tree.children.forEach(function (node) {
        applySidebarOrdering({
            tree: node,
            order: order[node.name] ||
                order[node.name.replace(MDX_EXTENSION_REGEX, '')],
        });
    });
    return tree;
}
var NavTreeComponent = function (_a) {
    var _b = _a.name, name = _b === void 0 ? '' : _b, children = _a.children, _c = _a.depth, depth = _c === void 0 ? 0 : _c, _d = _a.hideDivider, hideDivider = _d === void 0 ? false : _d, _e = _a.url, url = _e === void 0 ? '' : _e, _f = _a.title, title = _f === void 0 ? '' : _f, path = _a.path, rest = __rest(_a, ["name", "children", "depth", "hideDivider", "url", "title", "path"]);
    var w = 10;
    var isFolder = !url;
    var formattedTitle = title || formatTitle(name || '');
    var Faded = useAnimationComponent();
    var subTree = children &&
        children.map(function (x) {
            return (React.createElement(NavTreeComponent, __assign({ key: x.path || x.title }, x, { depth: depth + 1 })));
        });
    if (isFolder && depth > 0) {
        return (React.createElement(CollapsableTreeNode, __assign({ path: path, depth: depth, title: formattedTitle, subTree: subTree }, rest)));
    }
    if (isFolder) {
        return (React.createElement(Stack, __assign({ as: Faded, cascade: true, spacing: '0px' }, rest),
            React.createElement(Box, { my: '0.2em' },
                !hideDivider && React.createElement(Divider, null),
                React.createElement(Box, { py: '0.2em', pt: '1.4em', my: '0.2em', fontSize: '1.1em', fontWeight: 'semibold' }, formattedTitle)),
            subTree));
    }
    return (React.createElement(Stack, __assign({ spacing: '0px' }, rest),
        React.createElement(ComponentLink, { opacity: 0.8, py: '0.2em', my: '0.2em', href: url, isTruncated: true }, formattedTitle),
        subTree));
};
function CollapsableTreeNode(_a) {
    var title = _a.title, path = _a.path, depth = _a.depth, subTree = _a.subTree;
    var key = 'sidenav-state-' + path;
    var _b = useStorageState(typeof window === 'undefined' ? null : localStorage, key, ''), active = _b[0], setActive = _b[1];
    var _c = useDisclosure({
        defaultIsOpen: Boolean(active),
    }), onToggle = _c.onToggle, isOpen = _c.isOpen;
    useEffect(function () {
        setActive(isOpen ? 'true' : '');
    }, [isOpen]);
    return (React.createElement(Stack, { spacing: '0px' },
        React.createElement(Box, { display: 'flex', alignItems: 'center', cursor: 'pointer', onClick: onToggle, py: '0.2em', my: '0.2em' },
            React.createElement(Box, { mr: '0.4em', boxSize: '0.6em', opacity: 0.6, display: 'inline-block', as: isOpen ? CollapseDown : CollapseRight }),
            title),
        React.createElement(Collapse, { in: isOpen },
            React.createElement(Box, { ml: '20px' }, subTree))));
}
var CollapseRight = function (props) {
    return (React.createElement("svg", __assign({ viewBox: '0 0 5 8', fill: 'currentColor', xmlns: 'http://www.w3.org/2000/svg' }, props),
        React.createElement("path", { d: 'M0 0.724246C0 0.111374 0.681914 -0.223425 1.13107 0.168926L4.66916 3.25957C5.11028 3.6449 5.11028 4.3551 4.66916 4.74043L1.13107 7.83107C0.681913 8.22342 0 7.88863 0 7.27575V0.724246Z', fill: 'currentColor' })));
};
var CollapseDown = function (props) {
    return (React.createElement("svg", __assign({ viewBox: '0 0 8 6', fill: 'currentColor', xmlns: 'http://www.w3.org/2000/svg' }, props),
        React.createElement("path", { d: 'M7.27575 0.5C7.88863 0.5 8.22342 1.18191 7.83107 1.63107L4.74043 5.16916C4.3551 5.61028 3.6449 5.61028 3.25957 5.16916L0.168926 1.63107C-0.223425 1.18191 0.111375 0.5 0.724247 0.5L7.27575 0.5Z', fill: 'currentColor' })));
};
