var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import chokidar from 'chokidar';
import throttle from 'lodash/throttle';
import fs from 'fs';
import { pipe } from 'lodash/fp';
import path from 'path';
import extractFrontmatter from 'remark-extract-frontmatter';
import frontmatter from 'remark-frontmatter';
import addMeta from 'remark-mdx-metadata';
import slug from 'remark-slug';
import YAML from 'yaml';
import { generateTableOfContents } from './generateTableOfContents';
import { getMdxFilesIndex } from './getMdxFilesIndex';
import { injectCodeToPlayground } from './rehype/playground';
import { withMdx } from './withMdx';
import { formatTitle } from '../components/support';
var EXTENSIONS_TO_WATCH = ['.mdx', '.md'];
export function withDokz(nextConfig) {
    if (nextConfig === void 0) { nextConfig = {}; }
    // .on('change', writeMdxIndex)
    nextConfig.pageExtensions = unique(__spreadArrays((nextConfig.pageExtensions || []), [
        'mdx',
    ]));
    return withMdx({
        extension: /\.mdx?$/,
        onStart: function (_, options) {
            // only run once
            if (options.isServer) {
                return;
            }
            writeMdxIndex();
            if (process.env.NODE_ENV !== 'production') {
                var watcher = chokidar.watch(['./**/*.mdx', './**/*.md'], {
                    persistent: true,
                    ignoreInitial: true,
                });
                watcher.on('change', onFileChange);
                watcher.on('add', onFileChange);
                watcher.on('unlink', onFileChange);
            }
            else {
                writeMdxIndex();
            }
        },
        options: {
            remarkPlugins: [
                frontmatter,
                [extractFrontmatter, { yaml: YAML.parse }],
                slug,
                function () { return function (tree, vfile) {
                    var tableOfContents = generateTableOfContents(tree);
                    // console.log(vfile)
                    var cwd = vfile.cwd, contents = vfile.contents, _a = vfile.history, history = _a === void 0 ? [] : _a, data = vfile.data;
                    var filePath = history[0] || '';
                    if (process.env.DEBUG) {
                        console.log('frontmatter', data);
                    }
                    var plugin = pipe(addMeta({
                        meta: __assign(__assign({ 
                            // lastEdited: `${new Date().toISOString()}`,
                            name: formatTitle(filePath.split('/').slice(-1)[0] || '') }, data), { tableOfContents: tableOfContents }),
                    }));
                    plugin(tree);
                }; },
            ],
            rehypePlugins: [injectCodeToPlayground],
        },
    })(nextConfig);
}
function onFileChange(name) {
    var ext = path.extname(name);
    if (!EXTENSIONS_TO_WATCH.includes(ext)) {
        return;
    }
    writeMdxIndex();
}
var writeMdxIndex = throttle(function () {
    console.log('[ info ]  generating mdx sidebar file');
    return getMdxFilesIndex()
        .then(function (index) {
        return fs.promises.writeFile('sidebar.json', JSON.stringify(index, null, 4));
    })
        .catch(function (e) {
        console.error('could not write mdx sidebar file');
        console.error(e);
    });
}, 2000);
function unique(arr) {
    var u = {}, a = [];
    for (var i = 0, l = arr.length; i < l; ++i) {
        if (!u.hasOwnProperty(arr[i])) {
            a.push(arr[i]);
            u[arr[i]] = 1;
        }
    }
    return a;
}
