import * as parser from '@babel/parser';
import traverse from '@babel/traverse';
import get from 'lodash/get';
var fromDeclarations = function (declarations) {
    if (declarations === void 0) { declarations = []; }
    return Array.isArray(declarations) && declarations.length > 0
        ? declarations.map(function (declaration) { return get(declaration, 'id.name'); })
        : [];
};
var traverseOnExports = function (fn) { return function (node) {
    try {
        var ast = parser.parse(node.value, {
            sourceType: 'module',
        });
        var populated_1 = [];
        traverse(ast, {
            enter: function (path) {
                if (path.isExportDeclaration()) {
                    populated_1 = populated_1.concat(fn(path));
                    return;
                }
            },
        });
        return populated_1;
    }
    catch (err) {
        return [];
    }
}; };
export var getExportsVariables = traverseOnExports(function (path) {
    var type = get(path, 'node.declaration.type');
    switch (type) {
        case 'VariableDeclaration':
            return fromDeclarations(get(path, 'node.declaration.declarations', []));
        case 'FunctionDeclaration':
            var declaration = get(path, 'node.declaration', false);
            return fromDeclarations(declaration ? [declaration] : []);
        case 'Identifier':
            return get(path, 'node.declaration.name');
        default:
            console.error("Unexpected export type " + type + " in docz-utils/exports");
    }
});
